@@ -376,6 +376,8 @@ class TestSubsystemsCMakeBuild:
 
     """
     cmakelists = textwrap.dedent("""
+        set(CMAKE_CXX_COMPILER_WORKS 1)
+        set(CMAKE_CXX_ABI_COMPILED 1)
         cmake_minimum_required(VERSION 3.15)
         project(app CXX)
         message(STATUS "MYCMAKE VERSION=${CMAKE_VERSION}")
