@@ -61,3 +61,30 @@ def test_msbuildtoolchain_compiler_update():
     # because the test always run over vcvars that already activates it
     assert "amd64 - winsdk_version=None - vcvars_ver=14.38" in client.out
     assert "hello/0.1: _MSC_VER1938" in client.out
+
+
+@pytest.mark.tool("visual_studio")
+@pytest.mark.skipif(platform.system() != "Windows", reason="Only for windows")
+class TestTxtCommandLineMSBuild:
+
+    def test_declarative(self):
+        conanfile = textwrap.dedent("""
+            [generators]
+            MSBuildToolchain
+            """)
+        client = TestClient()
+        client.save({"conanfile.txt": conanfile})
+        client.run("install .")
+        self._check(client)
+
+    @staticmethod
+    def _check(client):
+        assert "conanfile.txt: Generator 'MSBuildToolchain' calling 'generate()'" in client.out
+        toolchain = client.load("conantoolchain.props")
+        assert "<?xml version" in toolchain
+
+    def test_command_line(self):
+        client = TestClient()
+        client.save({"conanfile.txt": ""})
+        client.run("install . -g MSBuildToolchain")
+        self._check(client)
