@@ -134,7 +134,7 @@ class TestFilters:
         c.save({"conanfile.py": GenConanfile()
                .with_class_attribute("author = 'myself'")
                .with_class_attribute("license = 'MIT'")
-               .with_class_attribute("url = 'http://url.com'")})
+               .with_class_attribute("url = 'https://url.com'")})
         c.run("graph info . ")
         assert "license: MIT" in c.out
         assert "author: myself" in c.out
@@ -154,7 +154,7 @@ class TestFilters:
         c.save({"conanfile.py": GenConanfile()
                .with_class_attribute("author = 'myself'")
                .with_class_attribute("license = 'MIT'")
-               .with_class_attribute("url = 'http://url.com'")})
+               .with_class_attribute("url = 'https://url.com'")})
         c.run("graph info . --filter=license --format=json")
         assert "author" not in c.out
         assert '"license": "MIT"' in c.out
@@ -415,7 +415,6 @@ class TestErrorsInGraph:
         assert exit_code == 0
 
 
-
 class TestInfoUpdate:
 
     def test_update(self):
@@ -502,3 +501,17 @@ def test_graph_info_bundle():
 
     c.run("graph info . -c tools.graph:vendor=build --build='lib*'")
     c.assert_listed_binary({"lib/1.0": (NO_SETTINGS_PACKAGE_ID, "Build")})
+
+
+def test_graph_info_provides_conflict_html():
+    """ This test also makes sure that the serialization of the GraphProvidesConflict works"""
+    tc = TestClient(light=True)
+    tc.save({"bar/conanfile.py": GenConanfile("bar", "1.0"),
+             "foo/conanfile.py": GenConanfile("foo", "1.0").with_provides("bar")})
+
+    tc.run("export bar")
+    tc.run("export foo")
+    tc.run("graph info --requires=bar/1.0 --requires=foo/1.0 --format=html", assert_error=True)
+    # It got properly serialized
+    assert '"type": "provide_conflict"' in tc.out
+    assert "Both 'bar/1.0' and 'foo/1.0' provide '['bar']'"
