@@ -391,6 +391,16 @@ class TestErrorsUx:
         c.run("install --requires=zlib/0.1@myuser/mychannel")
         c.assert_listed_require({"zlib/0.1@myuser/mychannel": "Downloaded (default)"})
 
+    def test_errors_missing_folder(self):
+        folder = temp_folder()
+        repo = os.path.join(folder, "repo")
+        mkdir(repo)
+        c = TestClient(light=True)
+        c.run(f"remote add local '{repo}'")
+        # shutil.rmtree(repo)
+        c.run("install --requires=zlib/[*] --build missing", assert_error=True)
+        assert "Cannot connect to 'local-recipes-index' repository, missing 'recipes'" in c.out
+
 
 class TestPythonRequires:
     @pytest.fixture(scope="class")
@@ -467,3 +477,78 @@ class TestUserChannel:
 
         tc.run(f"graph info --requires=pkg/[<2]", assert_error=True)
         assert f" Package 'pkg/[<2]' not resolved" in tc.out
+
+
+class TestResetRemote:
+    def test_resetting_remote_error(self):
+        # https://github.com/conan-io/conan/issues/18371
+        folder = temp_folder()
+        recipes_folder = os.path.join(folder, "recipes")
+        zlib_config = textwrap.dedent("""
+            versions:
+              "1.2.11":
+                folder: all
+            """)
+        zlib = textwrap.dedent("""
+            from conan import ConanFile
+            from conan.tools.files import load
+            class Zlib(ConanFile):
+                name = "zlib"
+                exports_sources = "*"
+                """)
+        save_files(recipes_folder,
+                   {"zlib/config.yml": zlib_config,
+                    "zlib/all/conanfile.py": zlib,
+                    "zlib/all/conandata.yml": "",
+                    "zlib/all/file.h": "//myheader"})
+
+        client = TestClient(light=True)
+        client.run(f"remote add local '{folder}'")
+        client.run("graph info --requires=zlib/[*]")
+
+        # This second --force destroys the previous remote database
+        client.run(f"remote add local '{folder}' --force")
+        client.run("install --requires=zlib/[*] --build=missing")
+        # It doesn't fail or crash anymore
+
+    def test_changing_revisions(self):
+        # https://github.com/conan-io/conan/issues/18371
+        folder = temp_folder()
+        recipes_folder = os.path.join(folder, "recipes")
+        zlib_config = textwrap.dedent("""
+            versions:
+              "1.2.11":
+                folder: all
+            """)
+        zlib = textwrap.dedent("""
+            from conan import ConanFile
+            from conan.tools.files import load
+            class Zlib(ConanFile):
+                name = "zlib"
+                exports_sources = "*"
+                def build(self):
+                    self.output.info(f"BUILDING: {load(self, 'file.h')}")
+            """)
+        save_files(recipes_folder,
+                   {"zlib/config.yml": zlib_config,
+                    "zlib/all/conanfile.py": zlib,
+                    "zlib/all/conandata.yml": "",
+                    "zlib/all/file.h": "//myheader"})
+
+        c = TestClient(light=True)
+        c.run(f"remote add local '{folder}'")
+        c.run("graph info --requires=zlib/[*]")
+        rev1 = "bd69839cb4c933336fceb32302aaf91f"
+
+        # Modify zlib code
+        save_files(recipes_folder, {"zlib/all/file.h": "//myheader 222"})
+        c.run("graph info --requires=zlib/[*] --update")
+        rev2 = "c912566276abca17d2fb5fb6fc957852"
+
+        c.run(f"remote add local '{folder}' --force")
+        c.run(f"install --requires=zlib/1.2.11#{rev2} --build=missing")  # works
+        c.run(f"install --requires=zlib/1.2.11#{rev1} --build=missing", assert_error=True)
+        assert ("WARN: A specific revision 'zlib/1.2.11#bd69839cb4c933336fceb32302aaf91f' was "
+                "requested, but it doesn't match the current available revision in source") in c.out
+        assert ("ERROR: The 'zlib/1.2.11' package has 'exports_sources' but sources "
+                "not found in local cache") in c.out
