@@ -409,6 +409,31 @@ def test_cmake_extra_dependencies():
            "             $<$<CONFIG:RELEASE>:MyOpenMPILib>)" in dep
 
 
+def test_cmake_extra_dependencies_components():
+    tc = TestClient()
+    dep = textwrap.dedent("""
+        from conan import ConanFile
+        class Pkg(ConanFile):
+            name = "dep"
+            version = "0.1"
+            def package_info(self):
+                self.cpp_info.set_property("cmake_extra_dependencies", ["MyOpenMPI"])
+                self.cpp_info.components["mycomp"].set_property("cmake_extra_interface_libs",
+                                                                ["MyOpenMPILib"])
+                self.cpp_info.components["mycomp"].libs = ["mycomplib"]
+                self.cpp_info.components["mycomp"].type = "static-library"
+                self.cpp_info.components["mycomp"].location = "lib/mycomp.a"
+        """)
+    tc.save({"conanfile.py": dep})
+    tc.run("create .")
+    args = f"-g CMakeDeps -c tools.cmake.cmakedeps:new={new_value}"
+    tc.run(f"install --requires=dep/0.1 {args}")
+    dep = tc.load("dep-Targets-release.cmake")
+    assert "find_dependency(MyOpenMPI REQUIRED )" in dep
+    assert "set_property(TARGET dep::mycomp APPEND PROPERTY INTERFACE_LINK_LIBRARIES\n" \
+           "             $<$<CONFIG:RELEASE>:MyOpenMPILib>)" in dep
+
+
 class TestRequiresToApp:
     def test_requires_to_application(self):
         c = TestClient()
@@ -544,7 +569,6 @@ class TestRequiresToApp:
         assert "automake::automake" not in targets
 
 
-
 def test_alias_cmakedeps_set_property():
     tc = TestClient()
     tc.save({"dep/conanfile.py": textwrap.dedent("""
@@ -601,7 +625,8 @@ def test_package_info_extra_variables():
             def package_info(self):
                 self.cpp_info.set_property("cmake_extra_variables", {"FOO": 42,
                                            "BAR": 42,
-                                           "CMAKE_GENERATOR_INSTANCE": "${GENERATOR_INSTANCE}/buildTools/",
+                                           "CMAKE_GENERATOR_INSTANCE":
+                                                 "${GENERATOR_INSTANCE}/buildTools/",
                                            "CACHE_VAR_DEFAULT_DOC": {"value": "hello world",
                                                                      "cache": True, "type": "PATH"}})
     """)
@@ -615,3 +640,27 @@ def test_package_info_extra_variables():
     assert 'set(CMAKE_GENERATOR_INSTANCE "${GENERATOR_INSTANCE}/buildTools/")' in target
     assert 'set(FOO 42)' in target
     assert 'set(CACHE_VAR_DEFAULT_DOC "hello world" CACHE PATH "CACHE_VAR_DEFAULT_DOC")' in target
+
+
+def test_target_defines_only():
+    client = TestClient()
+    conanfile = textwrap.dedent("""
+        from conan import ConanFile
+
+        class Pkg(ConanFile):
+            name = "pkg"
+            version = "0.1"
+
+            def package_info(self):
+                self.cpp_info.components["base"].includedirs = []
+                self.cpp_info.components["base"].defines = ["FOO=1"]
+                self.cpp_info.components["comp"].includedirs = ["include"]
+                self.cpp_info.components["comp"].requires = ["base"]
+    """)
+    client.save({"conanfile.py": conanfile})
+    client.run("create .")
+
+    client.run(f"install --requires=pkg/0.1 -g CMakeDeps -c tools.cmake.cmakedeps:new={new_value}")
+    target = client.load("pkg-Targets-release.cmake")
+    assert 'add_library(pkg::base INTERFACE IMPORTED)' in target
+    assert "# Requirement pkg::base => Full link: True" in target
