@@ -1,6 +1,5 @@
 import os
 import shutil
-import unittest
 from os.path import join
 
 import pytest
@@ -10,9 +9,10 @@ from conan.test.utils.test_files import temp_folder
 from conan.internal.util.files import mkdir, save, merge_directories, load
 
 
-class MergeDirectoriesTest(unittest.TestCase):
+class TestMergeDirectories:
 
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def setup(self):
         self.source = temp_folder()
         self.dest = temp_folder()
 
@@ -35,8 +35,7 @@ class MergeDirectoriesTest(unittest.TestCase):
         return ret
 
     def _assert_equals(self, list1, list2):
-        self.assertEqual(set([el.replace("/", "\\") for el in list1]),
-                          set([el.replace("/", "\\") for el in list2]))
+        assert set([el.replace("/", "\\") for el in list1]) == set([el.replace("/", "\\") for el in list2])
 
     def test_empty_dest_merge(self):
         files = ["file.txt", "subdir/file2.txt"]
@@ -54,7 +53,7 @@ class MergeDirectoriesTest(unittest.TestCase):
         merge_directories(self.source, self.dest)
         self._assert_equals(self._get_paths(self.dest), files + files_dest)
         # File from src overrides file from dest
-        self.assertEqual(load(join(self.dest, "file.txt")), "fromsrc")
+        assert load(join(self.dest, "file.txt")) == "fromsrc"
 
     def test_nested_directories(self):
         self.dest = join(self.source, "destination_dir")
@@ -68,9 +67,9 @@ class MergeDirectoriesTest(unittest.TestCase):
         merge_directories(self.source, self.dest)
         self._assert_equals(self._get_paths(self.dest), files + files_dest +
                             ['empty_folder/subempty_folder', ])
-        self.assertEqual(load(join(self.dest, "file.txt")), "fromsrc")
-        self.assertEqual(load(join(self.dest, "subdir2/file2.txt")), "fromdest")
-        self.assertEqual(load(join(self.dest, "subdir/file2.txt")), "fromsrc")
+        assert load(join(self.dest, "file.txt")) == "fromsrc"
+        assert load(join(self.dest, "subdir2/file2.txt")) == "fromdest"
+        assert load(join(self.dest, "subdir/file2.txt")) == "fromsrc"
 
     def test_same_directory(self):
         # Same directory cannot be merged, this should never happen
@@ -86,6 +85,6 @@ class MergeDirectoriesTest(unittest.TestCase):
         merge_directories(self.source, self.dest)
         shutil.rmtree(self.source)
         self._assert_equals(self._get_paths(self.dest), files + files_dest)
-        self.assertEqual(load(join(self.dest, "file.txt")), "fromsrc")
-        self.assertEqual(load(join(self.dest, "subdir2/file2.txt")), "fromdest")
-        self.assertEqual(load(join(self.dest, "subdir/file2.txt")), "fromsrc")
+        assert load(join(self.dest, "file.txt")) == "fromsrc"
+        assert load(join(self.dest, "subdir2/file2.txt")) == "fromdest"
+        assert load(join(self.dest, "subdir/file2.txt")) == "fromsrc"
