@@ -1,4 +1,4 @@
-import mock
+from unittest import mock
 import os
 import platform
 import pytest
