@@ -1,5 +1,5 @@
 import pytest
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 from conan.tools.apple.apple import is_apple_os
 from conan.tools.gnu.gnudeps_flags import GnuDepsFlags
