@@ -1,4 +1,4 @@
-import mock
+from unittest import mock
 import pytest
 
 from conan.internal.api.detect.detect_api import detect_arch
